class bughelper(object):
    def info(self,content):
        pass
    
    def data(self, content):
        bug = content["bug"]
        displayclues = content["clue"]
        text = ""
        for key in displayclues.keys():
            text += "%s\n" % key
            if displayclues[key]:
                text += "".join(["  - %s\n" % a for a in displayclues[key]])
        return "http://launchpad.net/bugs/%s %s - %s" % (bug.bugnumber, bug.infotable, 
                                                         text)

class bugnumbers(object):
    def data(self,content):
        x = content["bug"]
        return "%s (%s, %s) - %s" %(x.bugnumber, x.status, x.importance, x.summary)
        
    def comments(self,content):
        return "https://bugs.launchpad.net/ubuntu/+bug/%s Comments %i" %(int(content["bug"]),
                content["count"])
    
    def statistic(self,content):
        text = "Total: %i\n" %content["total"]
        for key in ["status","importance"]:
            text += "\n%s\n" %key
            for k in content[key]:
                text += "\t%s: %s\n"%(k,content[key][k])
        return text
        
